[Bf-blender-cvs] [ea8e95cc786] temp-lineart-embree: Merge remote-tracking branch 'origin/master' into temp-lineart-embree

YimingWu noreply at git.blender.org
Sun Mar 13 14:37:28 CET 2022


Commit: ea8e95cc7868d1e34b718444a952650cad3d7968
Author: YimingWu
Date:   Sun Mar 13 15:06:37 2022 +0800
Branches: temp-lineart-embree
https://developer.blender.org/rBea8e95cc7868d1e34b718444a952650cad3d7968

Merge remote-tracking branch 'origin/master' into temp-lineart-embree

===================================================================



===================================================================

diff --cc source/blender/gpencil_modifiers/intern/lineart/lineart_cpu.c
index 92184e2d2db,2f648d7ed4b..19d14d66454
--- a/source/blender/gpencil_modifiers/intern/lineart/lineart_cpu.c
+++ b/source/blender/gpencil_modifiers/intern/lineart/lineart_cpu.c
@@@ -2286,16 -2223,16 +2329,16 @@@ static void lineart_main_load_geometrie
      }
  
      if (use_ob->type == OB_MESH) {
-       use_mesh = use_ob->data;
+       use_mesh = BKE_object_get_evaluated_mesh(use_ob);
      }
      else {
-       /* If DEG_ITER_OBJECT_FLAG_DUPLI is set, the curve objects are going to have a mesh
-        * equivalent already in the object list, so ignore converting the original curve in this
-        * case. */
-       if (allow_duplicates) {
+       /* If DEG_ITER_OBJECT_FLAG_DUPLI is set, some curve objects may also have an evaluated mesh
+        * object in the list. To avoid adding duplicate geometry, ignore evaluated curve objects in
+        * those cases. */
+       if (allow_duplicates && BKE_object_get_evaluated_mesh(ob) != NULL) {
          continue;
        }
 -      use_mesh = BKE_mesh_new_from_object(depsgraph, use_ob, true, true);
 +      // use_mesh = BKE_mesh_new_from_object(depsgraph, use_ob, true, true);
      }
  
      /* In case we still can not get any mesh geometry data from the object */



More information about the Bf-blender-cvs mailing list